OutgoingPacket

Enum OutgoingPacket 

pub enum OutgoingPacket {
    Encrypted {
        opcode: u16,
        data: Bytes,
    },
    Simple {
        opcode: u16,
        data: Bytes,
    },
    Massive {
        opcode: u16,
        packets: Vec<Bytes>,
    },
}
A packet on its way out, before having been turned into a frame.

In turn, we still need to know what kind of frame it should end up as. Generally, one outgoing packet will result in a single frame, but multiple packets can be combined to a massive packet. This will span multiple frames, including an additional header.

Variants



Encrypted

A packet that shall be encrypted before being sent out.

Fields

opcode: u16
data: Bytes


Simple

A basic packet that doesn’t need any additional transformation.

Fields

opcode: u16
data: Bytes


Massive

A massive packet containing multiple inner packets that should be sent together.

Fields

opcode: u16
packets: Vec<Bytes>