IncomingPacket

Struct IncomingPacket 

pub struct IncomingPacket { /* private fields */ }
An incoming packet that has already gone through re-framing of massive packets or decryption. It is essentially a collection of bytes for a given opcode, nothing more.

Implementations

Source

impl IncomingPacket

pub fn new(opcode: u16, data: Bytes) -> IncomingPacket

Creates a new packet given the opcode and contained data.

pub fn consume(self) -> (u16, Bytes)

Consumes this packet, return the contained data.

pub fn opcode(&self) -> u16

pub fn data(&self) -> &[u8]